@@ -17,14 +17,13 @@
 import re
 from typing import Tuple
 from urllib.parse import quote as urlencode, urlparse
+from bs4 import BeautifulSoup, Tag
 
 import requests
 
 from gophian.error import GophianError
 
-GO_IMPORT_META_REGEX = re.compile(
-    r"<meta\s+name=\"?go-import\"?\s*content=\"(\S*) git (\S*)\"\s*/?>"
-)
+GO_IMPORT_META_CONTENT_REGEX = re.compile(r"(\S*) git (\S*)")
 
 
 def package_from_import_path(session: requests.Session, path: str) -> Tuple[str, str]:
@@ -45,17 +44,36 @@ def get_repo_meta(session: requests.Session, path: str) -> Tuple[str, str]:
     Get the root package and repo by recursively downloading and checking
     website pages for a 'go-import' meta tag.
     """
-    res = session.get("https://" + path, timeout=60, params={"go-get": "1"})
-    match = GO_IMPORT_META_REGEX.search(res.text)
-    if match is None:
+    res = session.get(
+        "https://" + path,
+        timeout=60,
+        params={"go-get": "1"},
+        headers={"Accept": "text/html,application/xhtml+xml,application/xml"},
+    )
+    soup = BeautifulSoup(res.text, "html.parser")
+
+    def is_go_import_meta(tag: Tag):
+        return (
+            tag.name == "meta"
+            and tag.get("name") == "go-import"
+            and tag.has_attr("content")
+        )
+
+    match = soup.find(is_go_import_meta)
+    parts = None
+    if match and isinstance(match, Tag):
+        content = match.get_attribute_list("content")[0]
+        if content:
+            parts = GO_IMPORT_META_CONTENT_REGEX.match(content)
+    if parts is None:
         parts = path.split("/")
         if len(parts[:-1]) < 1:
             raise NoRootRepoError(path)
         else:
             return get_repo_meta(session, "/".join(parts[:-1]))
     return (
-        match.group(1),
-        strip_git_suffix(match.group(2)),
+        parts.group(1),
+        strip_git_suffix(parts.group(2)),
     )
 
 
